@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,7 +20,7 @@
 #include <QTest>
 #include <QWidget>
 #include <QLabel>
-#include <klineedit.h>
+#include <KLineEdit>
 #include <QComboBox>
 #include <libkdepimakonadi/tagwidgets.h>
 #include <AkonadiWidgets/CollectionComboBox>
