@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2011-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2011-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ FilterActionMissingFolderDialog::FilterActionMissingFolderDialog(
     , mListwidget(nullptr)
 {
     setModal(true);
-    setWindowTitle(i18n("Select Folder"));
+    setWindowTitle(i18nc("@title:window", "Select Folder"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     QLabel *lab = new QLabel(i18n("Folder path was \"%1\".", argStr));
