@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,12 +28,10 @@
 #include <KSyntaxHighlighting/Theme>
 
 #include <KSharedConfig>
-#include <KMessageBox>
 #include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
-#include <QTemporaryFile>
 
 using namespace MailCommon;
 
@@ -65,15 +63,11 @@ FilterConvertToSieveResultDialog::FilterConvertToSieveResultDialog(QWidget *pare
     topLayout->addWidget(buttonBox);
 
     FilterconverttosievePurposeMenuWidget *purposeMenu = new FilterconverttosievePurposeMenuWidget(this, this);
-    if (purposeMenu->menu()) {
-        QPushButton *mShareButton = new QPushButton(i18n("Share..."), this);
-        mShareButton->setMenu(purposeMenu->menu());
-        mShareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
-        purposeMenu->setEditorWidget(mEditor->editor());
-        buttonBox->addButton(mShareButton, QDialogButtonBox::ActionRole);
-    } else {
-        delete purposeMenu;
-    }
+    QPushButton *shareButton = new QPushButton(i18n("Share..."), this);
+    shareButton->setMenu(purposeMenu->menu());
+    shareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+    purposeMenu->setEditorWidget(mEditor->editor());
+    buttonBox->addButton(shareButton, QDialogButtonBox::ActionRole);
 
     readConfig();
 }
