@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2019 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -20,11 +20,16 @@
 #ifndef MAILCOMMON_FOLDERTREEWIDGETPROXYMODEL_H
 #define MAILCOMMON_FOLDERTREEWIDGETPROXYMODEL_H
 
-#include <Collection>
-#include <EntityRightsFilterModel>
 #include "mailcommon_export.h"
 
+#include <Collection>
+#include <EntityRightsFilterModel>
+
 namespace MailCommon {
+/**
+ * @brief The FolderTreeWidgetProxyModel class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MAILCOMMON_EXPORT FolderTreeWidgetProxyModel : public Akonadi::EntityRightsFilterModel
 {
     Q_OBJECT
@@ -65,8 +70,9 @@ public:
     void readConfig();
 
     void setWarningThreshold(qreal threshold);
+
 protected:
-    bool acceptRow(int sourceRow, const QModelIndex &sourceParent) const override;
+    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
 
 private:
     class Private;
