@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -522,7 +522,7 @@ const QString SearchRule::asString() const
 {
     QString result = QLatin1String("\"") + QString::fromLatin1(mField) + QLatin1String("\" <");
     result += functionToString(mFunction);
-    result += QStringLiteral("> \"") + mContents + QStringLiteral("\"");
+    result += QLatin1String("> \"") + mContents + QLatin1String("\"");
 
     return result;
 }
