@@ -2,6 +2,8 @@
   Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
     Author Tobias Koenig <tokoe@kdab.com>
 
+  Copyright (c) 2019-2020 Laurent Montel <montel@kde.org>
+
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at your
@@ -29,6 +31,7 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QIcon>
+#include <QTextEdit>
 
 #include <QAction>
 #include <QPointer>
@@ -39,9 +42,9 @@ using namespace MailCommon;
 class Q_DECL_HIDDEN SnippetsManager::Private
 {
 public:
-    Private(SnippetsManager *qq, QWidget *parent)
+    Private(SnippetsManager *qq, QWidget *parentWidget)
         : q(qq)
-        , mParent(parent)
+        , mParent(parentWidget)
     {
     }
 
@@ -64,8 +67,8 @@ public:
 
     void slotAddNewDndSnippset(const QString &);
 
-    void updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text);
-    void initializeAction(const QString &newName, const QKeySequence &keySequence, const QString &text);
+    void updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment);
+    void initializeAction(const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment);
     void initializeActionCollection();
 
     QString replaceVariables(const QString &text);
@@ -76,9 +79,6 @@ public:
     SnippetsModel *mModel = nullptr;
     QItemSelectionModel *mSelectionModel = nullptr;
     KActionCollection *mActionCollection = nullptr;
-    QObject *mEditor = nullptr;
-    QByteArray mEditorInsertMethod;
-
     QAction *mAddSnippetAction = nullptr;
     QAction *mEditSnippetAction = nullptr;
     QAction *mDeleteSnippetAction = nullptr;
@@ -172,8 +172,14 @@ void SnippetsManager::Private::createSnippet(const QString &text)
         mModel->setData(index, dlg->name(), SnippetsModel::NameRole);
         mModel->setData(index, dlg->text(), SnippetsModel::TextRole);
         mModel->setData(index, dlg->keySequence().toString(), SnippetsModel::KeySequenceRole);
+        mModel->setData(index, dlg->keyword(), SnippetsModel::KeywordRole);
+        mModel->setData(index, dlg->subject(), SnippetsModel::SubjectRole);
+        mModel->setData(index, dlg->to(), SnippetsModel::ToRole);
+        mModel->setData(index, dlg->cc(), SnippetsModel::CcRole);
+        mModel->setData(index, dlg->bcc(), SnippetsModel::BccRole);
+        mModel->setData(index, dlg->attachment(), SnippetsModel::AttachmentRole);
 
-        Q_EMIT mModel->updateActionCollection(QString(), dlg->name(), dlg->keySequence(), dlg->text());
+        Q_EMIT mModel->updateActionCollection(QString(), dlg->name(), dlg->keySequence(), dlg->text(), dlg->subject(), dlg->to(), dlg->cc(), dlg->bcc(), dlg->attachment());
         mDirty = true;
         save();
     }
@@ -207,6 +213,12 @@ void SnippetsManager::Private::editSnippet()
     dlg->setGroupIndex(oldGroupIndex);
     dlg->setName(oldSnippetName);
     dlg->setText(index.data(SnippetsModel::TextRole).toString());
+    dlg->setKeyword(index.data(SnippetsModel::KeywordRole).toString());
+    dlg->setSubject(index.data(SnippetsModel::SubjectRole).toString());
+    dlg->setTo(index.data(SnippetsModel::ToRole).toString());
+    dlg->setCc(index.data(SnippetsModel::CcRole).toString());
+    dlg->setBcc(index.data(SnippetsModel::BccRole).toString());
+    dlg->setAttachment(index.data(SnippetsModel::AttachmentRole).toString());
     dlg->setKeySequence(
         QKeySequence::fromString(
             index.data(SnippetsModel::KeySequenceRole).toString()));
@@ -224,8 +236,14 @@ void SnippetsManager::Private::editSnippet()
         mModel->setData(index, dlg->name(), SnippetsModel::NameRole);
         mModel->setData(index, dlg->text(), SnippetsModel::TextRole);
         mModel->setData(index, dlg->keySequence().toString(), SnippetsModel::KeySequenceRole);
+        mModel->setData(index, dlg->keyword(), SnippetsModel::KeywordRole);
+        mModel->setData(index, dlg->subject(), SnippetsModel::SubjectRole);
+        mModel->setData(index, dlg->to(), SnippetsModel::ToRole);
+        mModel->setData(index, dlg->cc(), SnippetsModel::CcRole);
+        mModel->setData(index, dlg->bcc(), SnippetsModel::BccRole);
+        mModel->setData(index, dlg->attachment(), SnippetsModel::AttachmentRole);
 
-        Q_EMIT mModel->updateActionCollection(oldSnippetName, dlg->name(), dlg->keySequence(), dlg->text());
+        Q_EMIT mModel->updateActionCollection(oldSnippetName, dlg->name(), dlg->keySequence(), dlg->text(), dlg->subject(), dlg->to(), dlg->cc(), dlg->bcc(), dlg->attachment());
         mDirty = true;
         save();
     }
@@ -250,7 +268,7 @@ void SnippetsManager::Private::deleteSnippet()
 
     mModel->removeRow(index.row(), currentGroupIndex());
 
-    Q_EMIT mModel->updateActionCollection(snippetName, QString(), QKeySequence(), QString());
+    Q_EMIT mModel->updateActionCollection(snippetName, QString(), QKeySequence(), QString(), QString(), QString(), QString(), QString(), QString());
     mDirty = true;
     save();
 }
@@ -337,10 +355,6 @@ void SnippetsManager::Private::deleteSnippetGroup()
 
 void SnippetsManager::Private::insertSelectedSnippet()
 {
-    if (!mEditor) {
-        return;
-    }
-
     if (!mSelectionModel->hasSelection()) {
         return;
     }
@@ -351,35 +365,41 @@ void SnippetsManager::Private::insertSelectedSnippet()
     }
 
     const QString text = replaceVariables(index.data(SnippetsModel::TextRole).toString());
-    QMetaObject::invokeMethod(mEditor, mEditorInsertMethod.constData(), Qt::DirectConnection,
-                              Q_ARG(QString, text));
+    const QString subject = replaceVariables(index.data(SnippetsModel::SubjectRole).toString());
+    const QString to = index.data(SnippetsModel::ToRole).toString();
+    const QString cc = index.data(SnippetsModel::CcRole).toString();
+    const QString bcc = index.data(SnippetsModel::BccRole).toString();
+    const QString attachment = index.data(SnippetsModel::AttachmentRole).toString();
+    Q_EMIT q->insertSnippetInfo({subject, text, to, cc, bcc, attachment});
 }
 
 void SnippetsManager::Private::insertActionSnippet()
 {
-    if (!mEditor) {
-        return;
-    }
-
     QAction *action = qobject_cast<QAction *>(q->sender());
     if (!action) {
         return;
     }
 
     const QString text = replaceVariables(action->property("snippetText").toString());
-    QMetaObject::invokeMethod(mEditor, mEditorInsertMethod.constData(), Qt::DirectConnection,
-                              Q_ARG(QString, text));
+    const QString subject = replaceVariables(action->property("snippetSubject").toString());
+    const QString to = action->property("snippetTo").toString();
+    const QString cc = action->property("snippetCc").toString();
+    const QString bcc = action->property("snippetBcc").toString();
+    const QString attachment = action->property("snippetAttachment").toString();
+    Q_EMIT q->insertSnippetInfo({subject, text, to, cc, bcc, attachment});
 }
 
 void SnippetsManager::Private::initializeActionCollection()
 {
-    const QVector<SnippetsInfo> infos = mModel->snippetsInfo();
-    for (const SnippetsInfo &info : infos) {
-        initializeAction(info.newName, info.keySequence, info.text);
+    if (mActionCollection) {
+        const QVector<SnippetsInfo> infos = mModel->snippetsInfo();
+        for (const SnippetsInfo &info : infos) {
+            initializeAction(info.newName, info.keySequence, info.text, info.subject, info.to, info.cc, info.bcc, info.attachment);
+        }
     }
 }
 
-void SnippetsManager::Private::initializeAction(const QString &newName, const QKeySequence &keySequence, const QString &text)
+void SnippetsManager::Private::initializeAction(const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment)
 {
     const QString actionName = i18nc("@action", "Snippet %1", newName);
     const QString normalizedName = QString(actionName).replace(QLatin1Char(' '), QLatin1Char('_'));
@@ -390,14 +410,19 @@ void SnippetsManager::Private::initializeAction(const QString &newName, const QK
         insertActionSnippet();
     });
     action->setProperty("snippetText", text);
+    action->setProperty("snippetSubject", subject);
+    action->setProperty("snippetTo", to);
+    action->setProperty("snippetCc", cc);
+    action->setProperty("snippetBcc", bcc);
+    action->setProperty("snippetAttachment", attachment);
     action->setText(actionName);
     mActionCollection->setDefaultShortcut(action, keySequence);
 }
 
-void SnippetsManager::Private::updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text)
+void SnippetsManager::Private::updateActionCollection(const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment)
 {
     // remove previous action in case that the name changed
-    if (!oldName.isEmpty()) {
+    if (!oldName.isEmpty() && mActionCollection) {
         const QString actionName = i18nc("@action", "Snippet %1", oldName);
         const QString normalizedName = QString(actionName).replace(QLatin1Char(' '), QLatin1Char('_'));
 
@@ -408,7 +433,7 @@ void SnippetsManager::Private::updateActionCollection(const QString &oldName, co
     }
 
     if (!newName.isEmpty()) {
-        initializeAction(newName, keySequence, text);
+        initializeAction(newName, keySequence, text, subject, to, cc, bcc, attachment);
     }
 }
 
@@ -468,13 +493,13 @@ void SnippetsManager::Private::save()
     mDirty = false;
 }
 
-SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *parent, QWidget *widget)
+SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *parent, QWidget *parentWidget)
     : QObject(parent)
-    , d(new Private(this, widget))
+    , d(new Private(this, parentWidget))
 {
     d->mModel = SnippetsModel::instance();
-    connect(d->mModel, &SnippetsModel::updateActionCollection, this, [this](const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text) {
-        d->updateActionCollection(oldName, newName, keySequence, text);
+    connect(d->mModel, &SnippetsModel::updateActionCollection, this, [this](const QString &oldName, const QString &newName, const QKeySequence &keySequence, const QString &text, const QString &subject, const QString &to, const QString &cc, const QString &bcc, const QString &attachment) {
+        d->updateActionCollection(oldName, newName, keySequence, text, subject, to, cc, bcc, attachment);
     });
     d->mSelectionModel = new QItemSelectionModel(d->mModel);
     d->mActionCollection = actionCollection;
@@ -533,6 +558,9 @@ SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *p
 
     d->initializeActionCollection();
     d->selectionChanged();
+    connect(this, &SnippetsManager::insertSnippet, this, [this]() {
+        d->insertSelectedSnippet();
+    });
 }
 
 SnippetsManager::~SnippetsManager()
@@ -541,21 +569,6 @@ SnippetsManager::~SnippetsManager()
     delete d;
 }
 
-void SnippetsManager::setEditor(QObject *editor, const char *insertSnippetMethod, const char *dropSignal)
-{
-    d->mEditor = editor;
-    d->mEditorInsertMethod = insertSnippetMethod;
-
-    if (dropSignal) {
-        const int index
-            = editor->metaObject()->indexOfSignal(
-                  QMetaObject::normalizedSignature(dropSignal + 1).data());  // skip the leading '2'
-        if (index != -1) {
-            connect(editor, dropSignal, this, SLOT(insertSelectedSnippet()));
-        }
-    }
-}
-
 QAbstractItemModel *SnippetsManager::model() const
 {
     return d->mModel;
