@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ public:
     QString mLabel;
     QString mGid;
     MailCommon::TagWidget *mTagWidget = nullptr;
-    QList<MailCommon::Tag::Ptr> mTags;
+    QVector<MailCommon::Tag::Ptr> mTags;
     Akonadi::Tag mTag;
     QPushButton *mOkButton = nullptr;
 };
@@ -52,7 +52,7 @@ AddTagDialog::AddTagDialog(const QList<KActionCollection *> &actions, QWidget *p
     , d(new MailCommon::AddTagDialogPrivate)
 {
     setModal(true);
-    setWindowTitle(i18n("Add Tag"));
+    setWindowTitle(i18nc("@title:window", "Add Tag"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     d->mTagWidget = new MailCommon::TagWidget(actions, this);
@@ -76,7 +76,7 @@ AddTagDialog::~AddTagDialog()
     delete d;
 }
 
-void AddTagDialog::setTags(const QList<MailCommon::Tag::Ptr> &tags)
+void AddTagDialog::setTags(const QVector<MailCommon::Tag::Ptr> &tags)
 {
     d->mTags = tags;
 }
